from __future__ import print_function
from distroinfo.info import DistroInfo

from rdopkg.actionmods import rdoinfo
from rdopkg.utils import log
from rdopkg import helpers
from rdopkg import exception


def release(release_specified=None, repo=None, phase_specified=None,
            local_info=None, info_file=None):
    if release_specified and repo:
        log.info("The option -r and -R cannot be used at the same time")
        raise exception.UserAbort(exit_code=1)
    if not info_file:
        info_file = rdoinfo.info_file()
    if local_info:
        di = DistroInfo(info_file,
                        local_info=local_info)
    else:
        di = rdoinfo.get_distroinfo()
    info = di.get_info()
    releases = info['releases']
    if not release_specified and not phase_specified:
        for release in releases:
            if repo and repo not in [r.get('name') for r in release['repos']]:
                continue
            rdoinfo.print_release_info(release)
            print()
    elif release_specified:
        for release in releases:
            if release["name"] == release_specified:
                rdoinfo.print_release_info(release)
                break
        else:
            print("No release match your filter.")
    elif phase_specified:
        output = []
        for release in releases:
            if release["status"] == phase_specified:
                output.append(release["name"])
        if len(output) == 0:
            print("No release match your phase filter.")
        else:
            print(*output, sep="\n")



from rdopkg.action import Action, Arg


ACTIONS = [
    Action('release', help="show information about RDO releases",
           optional_args=[
               Arg('release_specified', shortcut='-r',
                   help="fetch info about specified release"),
               Arg('repo', shortcut='-R', metavar='REPO',
                   help="show the releases built for this repo "
                   "(e.g: el9s, el8s)"),
               Arg('phase_specified', shortcut='-s',
                   help="fetch info about release in specified phase"),
               Arg('local_info', shortcut='-l',
                   help="use local distroinfo repo found in specified path"),
               Arg('info_file', shortcut='-i',
                   help="use specified distroinfo info file")
           ])
]



import pytest

from rdopkg.cli import rdopkg
from rdopkg.actions.release.actions import *
from rdopkg.exception import UserAbort

import test_common as common


def test_release_raises_when_release_and_repos_options():
    with pytest.raises(UserAbort):
        release(release_specified='rel-1', repo='repo-1')


def test_release_with_repo_option_1(tmpdir, capsys):
    rdoinfo_path = common.prep_rdoinfo_test(tmpdir, 'sample-1')
    rv = release(local_info=rdoinfo_path, repo='el9s')
    cap = capsys.readouterr()
    output = cap.out
    assert "zed" in output
    assert "yoga" in output
    assert "xena" in output
    assert "wallaby" in output
    assert "victoria" not in output
    assert "ussuri" not in output


def test_release_with_repo_option_2_not_a_known_value(tmpdir, capsys):
    rdoinfo_path = common.prep_rdoinfo_test(tmpdir, 'sample-1')
    rv = release(local_info=rdoinfo_path, repo='not-a-known-value')
    cap = capsys.readouterr()
    output = cap.out
    assert "zed" not in output
    assert "yoga" not in output
    assert "xena" not in output
    assert "wallaby" not in output
    assert "victoria" not in output
    assert "ussuri" not in output


def test_release_with_repo_option_3_empty_value(tmpdir, capsys):
    rdoinfo_path = common.prep_rdoinfo_test(tmpdir, 'sample-1')
    rv = release(local_info=rdoinfo_path, repo='')
    cap = capsys.readouterr()
    output = cap.out
    assert "zed" in output
    assert "yoga" in output
    assert "xena" in output
    assert "wallaby" in output
    assert "victoria" in output
    assert "ussuri" in output
